"""
SIESTAstepper runs SIESTA step by step, designed for constrained calculations.
"""

# meta
__title__ = "SIESTAstepper"
__author__ = "Eftal Gezer"
__license__ = "GNU GPL v3"
__copyright__ = "Copyright 2022, Eftal Gezer"
__version__ = "1.1.0"

from .core import run, single_run, run_next, run_interrupted, single_run_interrupted, make_directories, copy_files, \
    ani_to_fdf, xyz_to_fdf, merge_ani, analysis, energy_diff, contfiles, update_cwd, update_log, update_cores,\
    update_conda, update_cont
